
dtstart="$values[DTSTART]"
[ -z "$dtstart" ] && dtstart=$(date +%Y%m%dT%H%M%S)

echo "$dtstart" |case "$dtstart" in
  *Z)
    sed -rn 's:^([0-9]{4})([0-9]{2})([0-9]{2})T([0-9]{2})([0-9]{2})([0-9]{2})Z$:\1-\2-\3 \4\:\5\:\6 UTC:p'
    ;;
  TZID*)
    sed -rn 's:^TZID=(.+)\:([0-9]{4})([0-9]{2})([0-9]{2})T([0-9]{2})([0-9]{2})([0-9]{2})$:TZ="\1" \2-\3-\4 \5\:\6\:\7:p'
    ;;
  *)
    sed -rn 's:^([0-9]{4})([0-9]{2})([0-9]{2})T([0-9]{2})([0-9]{2})([0-9]{2})$:\1-\2-\3 \4\:\5\:\6:p'
    ;;
esac |read dts_date

dts_year=$(date -d "$dts_date" +%Y)
dts_month=$(date -d "$dts_date" +%m)
dts_dom=$(date -d "$dts_date" +%d)
dts_dow=$(date -d "$dts_date" +%u)
dts_weekday=$(date -d "$dts_date" +%A)
dts_hour=$(date -d "$dts_date" +%H)
dts_min=$(date -d "$dts_date" +%M)
dts_sec=$(date -d "$dts_date" +%S)

rrule="$values[RRULE]"
rr_int="$(echo $rrule |sed -rn 's:^.*INTERVAL=([0-9]+)(;.*)?$:\1:p')"
rr_count="$(echo $rrule |sed -rn 's:^.*COUNT=([0-9]+)(;.*)?$:\1:p')"
rr_freq="$(echo $rrule |sed -rn 's:^.*FREQ=(YEARLY|MONTHLY|WEEKLY|DAILY)(;.*)?$:\1:p')"
rr_uyear="$(echo $rrule |sed -rn 's:^.*UNTIL=([0-9]{4})([0-9]{2})([0-9]{2})T[0-9]{6}Z(;.*)?$:\1:p')"
rr_umonth="$(echo $rrule |sed -rn 's:^.*UNTIL=([0-9]{4})([0-9]{2})([0-9]{2})T[0-9]{6}Z(;.*)?$:\2:p')"
rr_uday="$(echo $rrule |sed -rn 's:^.*UNTIL=([0-9]{4})([0-9]{2})([0-9]{2})T[0-9]{6}Z(;.*)?$:\3:p')"
rr_udate="$(echo $rrule |sed -rn 's:^.*UNTIL=([0-9]{4})([0-9]{2})([0-9]{2})T([0-9]{2})([0-9]{2})([0-9]{2})Z(;.*)?$:\1-\2-\3 \4\:\5\:\6:p')"
if [ -n "$rr_count" ]; then
  rr_limit=COUNT
elif [ -n "$rr_uyear" ]; then
  rr_limit=UNTIL
else
  rr_limit=ETERN
fi

coursemail=""

echo '<div id="'${id}'" class="course">'
echo '<form action="/?action=update_course" method="POST">'
echo '<input type="hidden" name="course" value="'${id}'"/>'
echo '  <div class="section basic">'
echo '    <span class="sectitle">'$values[SUMMARY]'</span>'
echo '    <span class="text">'$(date -d "$dts_date" "+%A %B %d, %Y - %H:%M") $(l10n t_oclock)'</span>'
[ "$rr_int" -eq 1 ] \
&& echo '<span class="text">'$(l10n s$rr_freq)'</span>' \
|| echo '<span class="text">'$(l10n t_every) ${rr_int} $(l10n $rr_freq)'</span>'
case "$rr_limit" in
  COUNT)
    m1=$(echo $rr_freq |sed -r "s:DAILY:day:g;s:WEEKLY:week:g;s:MONTHLY:month:g;s:YEARLY:year:g;")
    m2=$(($rr_int * $rr_count))
    echo '<span class="text">'$(l10n t_until) $(date -d "$dts_date + $m2 $m1" "+%A %B %d, %Y - %H:%M")'</span>'
    ;;
  UNTIL)
    echo '<span class="text">'$(l10n t_until) $(date -d "$rr_udate" "+%A %B %d, %Y - %H:%M")'</span>'
    ;;
esac
echo '  </div>'

echo '  <div class="section COMMENT">'
echo '    <span class="sectitle">'$(l10n COMMENT)'</span>'
for n in COMMENT COMMENT{0..10}; do [ -n "$values[$n]" ] &&\
  echo '    <p class="item COMMENT">'$(echo "$values[$n]" |sed -r "s:$:<br/>:g" )'</p>'
done
echo '  </div>'

echo '  <div class="section attendance">'
echo '    <span class="sectitle">'$(l10n course_attendance)'</span>'
sed -rn 's:'$id'\t(.+)$:\1:p' "$_DATA/mappings/attendance" |while read each; do
  n_last="$(  sed -rn 's:^N(;.+)*\:([^;]*;){0} *([^;]*).*$:\3:p' "$_DATA/vcard/$each")"
  n_first="$( sed -rn 's:^N(;.+)*\:([^;]*;){1} *([^;]*).*$:\3:p' "$_DATA/vcard/$each")"
  n_middle="$(sed -rn 's:^N(;.+)*\:([^;]*;){2} *([^;]*).*$:\3:p' "$_DATA/vcard/$each")"
  n_pre="$(   sed -rn 's:^N(;.+)*\:([^;]*;){3} *([^;]*).*$:\3:p' "$_DATA/vcard/$each")"
  n_post="$(  sed -rn 's:^N(;.+)*\:([^;]*;){4} *([^;]*).*$:\3:p' "$_DATA/vcard/$each")"
  aname="${n_pre} ${n_first} ${n_middle} ${n_last} ${n_post}"
  echo '    <a class="attendance" href="/?page=attendees#'$each'">'$aname'</a>'

  coursemail="$coursemail$(sed -rn 's:^EMAIL(;.+)*\:(.+)\r$:\2,:p' "$_DATA/vcard/$each")"
done
echo '  </div>'

echo '  <div class="section control">'
echo '    <a class="item control" href="?action=edit_course&course='${id}'">'$(l10n edit)'</a>'
echo '    <a class="item control" href="?export=ical&course='${id}'">'$(l10n ics_export)'</a>'
echo '    <a class="item control" href="mailto:noone@vuesch.de?bcc='$coursemail'">'$(l10n course_mail)'</a>'
echo '  </div>'
echo '<input type="hidden" name="UID" value="'$values["UID"]'"/>'
echo '</form>'
echo '</div>'

